/* 
 *  libpinyin
 *  Library to deal with pinyin.
 *  
 *  Copyright (C) 2017 Peng Wu <alexepico@gmail.com>
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZHUYIN_CUSTOM2_H
#define ZHUYIN_CUSTOM2_H

#include "pinyin_custom2.h"
#include <glib.h>

G_BEGIN_DECLS


#define ZHUYIN_AMB_C_CH PINYIN_AMB_C_CH
#define ZHUYIN_AMB_S_SH PINYIN_AMB_S_SH
#define ZHUYIN_AMB_Z_ZH PINYIN_AMB_Z_ZH
#define ZHUYIN_AMB_F_H PINYIN_AMB_F_H
#define ZHUYIN_AMB_G_K PINYIN_AMB_G_K
#define ZHUYIN_AMB_L_N PINYIN_AMB_L_N
#define ZHUYIN_AMB_L_R PINYIN_AMB_L_R
#define ZHUYIN_AMB_AN_ANG PINYIN_AMB_AN_ANG
#define ZHUYIN_AMB_EN_ENG PINYIN_AMB_EN_ENG
#define ZHUYIN_AMB_IN_ING PINYIN_AMB_IN_ING
#define ZHUYIN_AMB_ALL PINYIN_AMB_ALL


G_END_DECLS

#endif
